@@ -1,4 +1,3 @@
-
 """
 vtelem - A queue that stores change events that can be completely drained on
          command.
@@ -14,22 +13,21 @@ from . import EventType
 
 
 class EventQueue:
-    """ A queue for storing primitive-data change events. """
+    """A queue for storing primitive-data change events."""
 
     def __init__(self) -> None:
-        """ Construct an empty queue. """
+        """Construct an empty queue."""
 
         self.queue: Queue = Queue()
         self.lock = threading.Lock()
 
-    def enqueue(self, channel: str, prev: EventType,
-                curr: EventType) -> None:
-        """ Put an event into the queue. """
+    def enqueue(self, channel: str, prev: EventType, curr: EventType) -> None:
+        """Put an event into the queue."""
 
         self.queue.put((channel, prev, curr))
 
     def consume(self) -> List[Tuple[str, EventType, EventType]]:
-        """ Get all of the current events in the queue as a list. """
+        """Get all of the current events in the queue as a list."""
 
         result = []
         with self.lock:
