@@ -1,4 +1,3 @@
-
 """
 vtelem - Uses daemon machinery to make servicing queues in threads simple.
 """
@@ -13,27 +12,31 @@ from .telemetry_environment import TelemetryEnvironment
 
 
 class QueueDaemon(DaemonBase):
-    """ Implements a daemon thread for servicing queues. """
+    """Implements a daemon thread for servicing queues."""
 
-    def __init__(self, name: str, input_stream: Queue,
-                 elem_handle: Callable,
-                 env: TelemetryEnvironment = None,
-                 time_keeper: Any = None) -> None:
-        """ Construct a new queue daemon. """
+    def __init__(
+        self,
+        name: str,
+        input_stream: Queue,
+        elem_handle: Callable,
+        env: TelemetryEnvironment = None,
+        time_keeper: Any = None,
+    ) -> None:
+        """Construct a new queue daemon."""
 
         super().__init__(name, env, time_keeper)
         self.queue = input_stream
         self.handle = elem_handle
 
         def stop_injector() -> None:
-            """ Put a None into the queue as the signal for stopping. """
+            """Put a None into the queue as the signal for stopping."""
             self.queue.put(None)
             self.queue.join()
 
         self.function["inject_stop"] = stop_injector
 
     def run(self, *_, **__) -> None:
-        """ Continue servicing the queue until None is de-queued. """
+        """Continue servicing the queue until None is de-queued."""
 
         elem = self.queue.get()
         while elem is not None:
