@@ -1,4 +1,3 @@
-
 """
 vtelem - An interface for setting up and tearing down outgoing udp streams.
 """
@@ -17,7 +16,7 @@ LOG = logging.getLogger(__name__)
 
 
 class UdpClientManager(LockEntity):
-    """ A class for managing outgoing udp streams. """
+    """A class for managing outgoing udp streams."""
 
     def __init__(self, writer: StreamWriter) -> None:
         """
@@ -54,36 +53,41 @@ class UdpClientManager(LockEntity):
         self.writer.error_handle = self.closer
 
     def client_name(self, sock_id: int) -> Tuple[str, int]:
-        """ Get the host and port of a client. """
+        """Get the host and port of a client."""
 
         assert sock_id in self.clients
         return self.clients[sock_id][0].getsockname()
 
     def add_client(self, host: Tuple[str, int]) -> Tuple[int, int]:
-        """ Add a new client connection by hostname and port. """
+        """Add a new client connection by hostname and port."""
 
         sock = create_udp_socket(host)
         mtu = discover_mtu(sock)
-        mtu -= (60 + 8)  # subtract ip and udp header space
+        mtu -= 60 + 8  # subtract ip and udp header space
         sock_file = sock.makefile("wb")
         sock_file.flush()
         with self.lock:
             sock_id = self.writer.add_stream(sock_file)
             self.clients[sock_id] = (sock, sock_file)
             name = sock.getsockname()
-        LOG.info("adding stream client '%s:%d' -> '%s:%d'", name[0], name[1],
-                 host[0], host[1])
+        LOG.info(
+            "adding stream client '%s:%d' -> '%s:%d'",
+            name[0],
+            name[1],
+            host[0],
+            host[1],
+        )
         return sock_id, mtu
 
     def remove_all(self) -> None:
-        """ Remove all active clients. """
+        """Remove all active clients."""
 
         with self.lock:
             for sock_id in list(self.clients.keys()):
                 self.remove_client(sock_id)
 
     def remove_client(self, sock_id: int) -> None:
-        """ Remove a client connection by integer identifier, closes it. """
+        """Remove a client connection by integer identifier, closes it."""
 
         with self.lock:
             if self.writer.remove_stream(sock_id):
