@@ -1,4 +1,3 @@
-
 """
 vtelem - Utilities for calculating maximum transmission-unit sizes.
 """
@@ -18,16 +17,17 @@ DEFAULT_MTU = 1500 - (60 + 8)
 
 
 class SocketConstants(IntEnum):
-    """ Some platform definitions necessary for mtu discovery. """
+    """Some platform definitions necessary for mtu discovery."""
 
     IP_MTU = 14
     IP_MTU_DISCOVER = 10
     IP_PMTUDISC_DO = 2
 
 
-def create_udp_socket(host: Tuple[str, int],
-                      is_client: bool = True) -> socket.SocketType:
-    """ Create a UDP socket, set to a requested peer address. """
+def create_udp_socket(
+    host: Tuple[str, int], is_client: bool = True
+) -> socket.SocketType:
+    """Create a UDP socket, set to a requested peer address."""
 
     assert sys.platform == "linux"
 
@@ -45,9 +45,11 @@ def create_udp_socket(host: Tuple[str, int],
     return sock
 
 
-def discover_mtu(sock: socket.SocketType,
-                 probe_size: int = DEFAULT_MTU,
-                 app_id_basis: float = None) -> int:
+def discover_mtu(
+    sock: socket.SocketType,
+    probe_size: int = DEFAULT_MTU,
+    app_id_basis: float = None,
+) -> int:
     """
     Send a large frame and indicate that we want to perform mtu discovery, and
     not fragment any frames.
@@ -55,10 +57,14 @@ def discover_mtu(sock: socket.SocketType,
 
     # see ip(7), force the don't-fragment flag and perform mtu discovery
     # such that the socket object can be queried for actual mtu upon error
-    orig_val = sock.getsockopt(socket.IPPROTO_IP,
-                               SocketConstants.IP_MTU_DISCOVER)
-    sock.setsockopt(socket.IPPROTO_IP, SocketConstants.IP_MTU_DISCOVER,
-                    SocketConstants.IP_PMTUDISC_DO)
+    orig_val = sock.getsockopt(
+        socket.IPPROTO_IP, SocketConstants.IP_MTU_DISCOVER
+    )
+    sock.setsockopt(
+        socket.IPPROTO_IP,
+        SocketConstants.IP_MTU_DISCOVER,
+        SocketConstants.IP_PMTUDISC_DO,
+    )
 
     try:
         count = sock.send(build_dummy_frame(probe_size, app_id_basis).raw()[0])
@@ -67,8 +73,9 @@ def discover_mtu(sock: socket.SocketType,
         pass
 
     # restore the original value
-    sock.setsockopt(socket.IPPROTO_IP, SocketConstants.IP_MTU_DISCOVER,
-                    orig_val)
+    sock.setsockopt(
+        socket.IPPROTO_IP, SocketConstants.IP_MTU_DISCOVER, orig_val
+    )
 
     return sock.getsockopt(socket.IPPROTO_IP, SocketConstants.IP_MTU)
 
@@ -87,8 +94,9 @@ def get_free_tcp_port(interface_ip: str = "0.0.0.0") -> int:
     return port
 
 
-def discover_ipv4_mtu(host: Tuple[str, int],
-                      probe_size: int = DEFAULT_MTU) -> int:
+def discover_ipv4_mtu(
+    host: Tuple[str, int], probe_size: int = DEFAULT_MTU
+) -> int:
     """
     Determine the maximum transmission unit for an IPv4 payload to a provided
     host.
@@ -97,7 +105,14 @@ def discover_ipv4_mtu(host: Tuple[str, int],
     sock = create_udp_socket(host)
     result = discover_mtu(sock, probe_size)
     name = sock.getsockname()
-    LOG.info("discovered mtu to (%s:%d -> %s:%d) is %d (probe size: %d)",
-             host[0], host[1], name[0], name[1], result, probe_size)
+    LOG.info(
+        "discovered mtu to (%s:%d -> %s:%d) is %d (probe size: %d)",
+        host[0],
+        host[1],
+        name[0],
+        name[1],
+        result,
+        probe_size,
+    )
     sock.close()
     return result
